@@ -1,30 +1,47 @@
-# SPDX-FileCopyrightText: 2020 2020
 #
-# SPDX-License-Identifier: Apache-2.0
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+
+from selenium.webdriver.common.by import By
+from selenium.webdriver.support.ui import WebDriverWait
 
 from ..base_component import Selector
 from .base_control import BaseControl
-from selenium.webdriver.support.ui import WebDriverWait
-from selenium.webdriver.common.by import By
+
 
 class Toggle(BaseControl):
     """
     Entity_Component : Button
     """
+
     def __init__(self, browser, container):
         """
-            :param browser: The selenium webdriver
-            :param container: The locator of the container where the control is located in. 
+        :param browser: The selenium webdriver
+        :param container: The locator of the container where the control is located in.
         """
-        super(Toggle, self).__init__(browser, container)
+        super().__init__(browser, container)
         self.elements.update(
             {
                 "toggle_btn": Selector(
-                    select=container.select + ' [data-test="option"] [data-test="label"]'
+                    select=container.select
+                    + ' [data-test="option"] [data-test="label"]'
                 ),
                 "selected": Selector(
-                    select=container.select + ' [data-test="option"][aria-checked="true"] [data-test="label"]'
-                )
+                    select=container.select
+                    + ' [data-test="option"][aria-checked="true"] [data-test="label"]'
+                ),
             }
         )
         self.browser = browser
@@ -36,7 +53,7 @@ class Toggle(BaseControl):
             :param value: the value to select
             :return: Bool if successful in selection, else raises an error
         """
-        for each in self.get_elements('toggle_btn'):
+        for each in self.get_elements("toggle_btn"):
             if each.text.lower() == value.lower():
                 self._wait_to_be_clickable(each)
                 return True
@@ -50,11 +67,12 @@ class Toggle(BaseControl):
                 return True
             except:
                 return False
-        WebDriverWait(self.browser,10).until(try_click)
+
+        WebDriverWait(self.browser, 10).until(try_click)
 
     def get_value(self):
         """
         Returns the value of the toggle element
             :return: Str the text for the toggle element
         """
-        return self.selected.text.strip()
\ No newline at end of file
+        return self.selected.text.strip()
